@@ -23,6 +23,7 @@ from aiida.manage.manager import get_manager
 from aiida.orm.utils.links import LinkManager, LinkTriple
 from aiida.orm.utils.repository import Repository
 from aiida.orm.utils.node import AbstractNodeMeta, validate_attribute_extra_key
+from aiida.orm import autogroup
 
 from ..comments import Comment
 from ..computers import Computer
@@ -163,6 +164,20 @@ class Node(Entity, metaclass=AbstractNodeMeta):
         # pylint: disable=no-self-use
         return True
 
+    def validate_storability(self):
+        """Verify that the current node is allowed to be stored.
+
+        :raises `aiida.common.exceptions.StoringNotAllowed`: if the node does not match all requirements for storing
+        """
+        from aiida.plugins.entry_point import is_registered_entry_point
+
+        if not self._storable:
+            raise exceptions.StoringNotAllowed(self._unstorable_message)
+
+        if not is_registered_entry_point(self.__module__, self.__class__.__name__, groups=('aiida.node', 'aiida.data')):
+            msg = 'class `{}:{}` does not have registered entry point'.format(self.__module__, self.__class__.__name__)
+            raise exceptions.StoringNotAllowed(msg)
+
     @classproperty
     def class_node_type(cls):
         """Returns the node type of this node (sub) class."""
@@ -998,11 +1013,10 @@ class Node(Entity, metaclass=AbstractNodeMeta):
                 'the `use_cache` argument is deprecated and will be removed in `v2.0.0`', AiidaDeprecationWarning
             )
 
-        if not self._storable:
-            raise exceptions.StoringNotAllowed(self._unstorable_message)
-
         if not self.is_stored:
 
+            # Call `validate_storability` directly and not in `_validate` in case sub class forgets to call the super.
+            self.validate_storability()
             self._validate()
 
             # Verify that parents are already stored. Raises if this is not the case.
@@ -1024,18 +1038,9 @@ class Node(Entity, metaclass=AbstractNodeMeta):
                 self._store(with_transaction=with_transaction, clean=True)
 
             # Set up autogrouping used by verdi run
-            from aiida.orm.autogroup import current_autogroup, Autogroup, VERDIAUTOGROUP_TYPE
-            from aiida.orm import Group
-
-            if current_autogroup is not None:
-                if not isinstance(current_autogroup, Autogroup):
-                    raise exceptions.ValidationError('`current_autogroup` is not of type `Autogroup`')
-
-                if current_autogroup.is_to_be_grouped(self):
-                    group_label = current_autogroup.get_group_name()
-                    if group_label is not None:
-                        group = Group.objects.get_or_create(label=group_label, type_string=VERDIAUTOGROUP_TYPE)[0]
-                        group.add_nodes(self)
+            if autogroup.CURRENT_AUTOGROUP is not None and autogroup.CURRENT_AUTOGROUP.is_to_be_grouped(self):
+                group = autogroup.CURRENT_AUTOGROUP.get_or_create_group()
+                group.add_nodes(self)
 
         return self
 
