@@ -3,16 +3,17 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 
+
+
 from aiida.tools.dbimporters.baseclasses import (DbImporter, DbSearchResults,
                                                  CifEntry)
 
 
-
 class IcsdImporterExp(Exception):
     pass
 
@@ -65,7 +66,7 @@ class IcsdDbImporter(DbImporter):
 
         or (if e.g. you get an URLError with Errno 111 (Connection refused)
         upon querying)::
-        
+
             ssh -L 3306:localhost:3306 -L 8010:localhost:80 username@hostname.com
 
     :param user: mysql database username (default: dba)
@@ -83,15 +84,15 @@ class IcsdDbImporter(DbImporter):
 
     def __init__(self, **kwargs):
 
-        self.db_parameters = {"server": "",
-                              "urladd": "index.php?",
-                              "querydb": True,
-                              "dl_db": "icsd",
-                              "host": "",
-                              "user": "dba",
-                              "passwd": "sql",
-                              "db": "icsd",
-                              "port": "3306",
+        self.db_parameters = {'server': '',
+                              'urladd': 'index.php?',
+                              'querydb': True,
+                              'dl_db': 'icsd',
+                              'host': '',
+                              'user': 'dba',
+                              'passwd': 'sql',
+                              'db': 'icsd',
+                              'port': '3306',
         }
         self.setup_db(**kwargs)
 
@@ -105,54 +106,49 @@ class IcsdDbImporter(DbImporter):
         :return: SQL query predicate
         """
         for e in values:
-            if not isinstance(e, (int, long)) and not isinstance(e, basestring):
+            if not isinstance(e, int) and not isinstance(e, str):
                 raise ValueError("incorrect value for keyword '" + alias + \
                                  "' -- only integers and strings are accepted")
-        return key + " IN (" + ", ".join(map(lambda i: str(int(i)),
-                                             values)) + ")"
+        return '{} IN ({})'.format(key, ', '.join(str(int(i)) for i in values))
 
     def _str_exact_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying string fields.
         """
         for e in values:
-            if not isinstance(e, (int, long)) and not isinstance(e, basestring):
+            if not isinstance(e, int) and not isinstance(e, str):
                 raise ValueError("incorrect value for keyword '" + alias + \
                                  "' -- only integers and strings are accepted")
-        return key + \
-               " IN (" + ", ".join(map(lambda f: "'" + str(f) + "'", \
-                                       values)) + ")"
+        return '{} IN ({})'.format(key, ', '.join("'{}'".format(f) for f in values))
 
     def _formula_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying formula fields.
         """
         for e in values:
-            if not isinstance(e, basestring):
+            if not isinstance(e, str):
                 raise ValueError("incorrect value for keyword '" + alias + \
                                  "' -- only strings are accepted")
         return self._str_exact_clause(key, \
                                      alias, \
-                                     map(lambda f: str(f), \
-                                         values))
+                                     [str(f) for f in values])
 
     def _str_fuzzy_clause(self, key, alias, values):
         """
         Return SQL query predicate for fuzzy querying of string fields.
         """
         for e in values:
-            if not isinstance(e, (int, long)) and not isinstance(e, basestring):
+            if not isinstance(e, int) and not isinstance(e, str):
                 raise ValueError("incorrect value for keyword '" + alias + \
                                  "' -- only integers and strings are accepted")
-        return " OR ".join(map(lambda s: key + \
-                                         " LIKE '%" + str(s) + "%'", values))
+        return ' OR '.join("{} LIKE '%{}%'".format(key, s) for s in values)
 
     def _composition_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying elements in formula fields.
         """
         for e in values:
-            if not isinstance(e, basestring):
+            if not isinstance(e, str):
                 raise ValueError("incorrect value for keyword '" + alias + \
                                  "' -- only strings are accepted")
         # SUM_FORM in the ICSD always stores a numeral after the element name,
@@ -161,44 +157,37 @@ class IcsdDbImporter(DbImporter):
         # or at the end of the formula expression (no space after).
         # Be aware that one needs to check that space/beginning of line before and ideally also space/end of line
         # after, because I found that capitalization of the element name is not enforced in these queries.
-        return " AND ".join(map(lambda e: "SUM_FORM REGEXP '(^|\ )" + e + "[0-9\.]+($|\ )'", values))
+        return ' AND '.join(r'SUM_FORM REGEXP \'(^|\ ){}[0-9\.]+($|\ )\''.format(e) for e in values)
 
     def _double_clause(self, key, alias, values, precision):
         """
         Return SQL query predicate for querying double-valued fields.
         """
         for e in values:
-            if not isinstance(e, (int, long)) and not isinstance(e, float):
+            if not isinstance(e, int) and not isinstance(e, float):
                 raise ValueError("incorrect value for keyword '" + alias + \
                                  "' -- only integers and floats are accepted")
-        return " OR ".join(map(lambda d: key + \
-                                         " BETWEEN " + \
-                                         str(d - precision) + " AND " + \
-                                         str(d + precision), \
-                               values))
-
+        return ' OR '.join('{} BETWEEN {} AND {}'.format(key, d-precision, d+precision) for d in values)
 
     def _crystal_system_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying crystal_system.
         """
         valid_systems = {
-            "cubic": "CU",
-            "hexagonal": "HE",
-            "monoclinic": "MO",
-            "orthorhombic": "OR",
-            "tetragonal": "TE",
-            "trigonal": "TG",
-            "triclinic": "TC"
+            'cubic': 'CU',
+            'hexagonal': 'HE',
+            'monoclinic': 'MO',
+            'orthorhombic': 'OR',
+            'tetragonal': 'TE',
+            'trigonal': 'TG',
+            'triclinic': 'TC'
         }  # from icsd accepted crystal systems
 
         for e in values:
-            if not isinstance(e, (int, long)) and not isinstance(e, basestring):
+            if not isinstance(e, int) and not isinstance(e, str):
                 raise ValueError("incorrect value for keyword '" + alias + \
                                  "' -- only strings are accepted")
-        return key + \
-               " IN (" + ", ".join(map(lambda f: "'" + valid_systems[f.lower()] + "'", \
-                                       values)) + ")"
+        return key + ' IN (' + ', '.join("'" + valid_systems[f.lower()] + "'" for f in values) + ')'
 
     def _length_clause(self, key, alias, values):
         """
@@ -272,10 +261,10 @@ class IcsdDbImporter(DbImporter):
         :param v: corresponding values
         :return retval: string
         """
-        if k == "mineral_name":
-            retval = "M=" + v
-        elif k == "chemical_name":
-            retval = "C=" + v
+        if k == 'mineral_name':
+            retval = 'M=' + v
+        elif k == 'chemical_name':
+            retval = 'C=' + v
         return retval
 
     def _parse_volume(k, v):
@@ -285,20 +274,20 @@ class IcsdDbImporter(DbImporter):
         :param v: corresponding values
         :return retval: string
         """
-        if k == "volume":
-            return "v=" + v
-        elif k == "a":
-            return "a=" + v
-        elif k == "b":
-            return "b=" + v
-        elif k == "c":
-            return "c=" + v
-        elif k == "alpha":
-            return "al=" + v
-        elif k == "beta":
-            return "be=" + v
-        elif k == "gamma":
-            return "ga=" + v
+        if k == 'volume':
+            return 'v=' + v
+        elif k == 'a':
+            return 'a=' + v
+        elif k == 'b':
+            return 'b=' + v
+        elif k == 'c':
+            return 'c=' + v
+        elif k == 'alpha':
+            return 'al=' + v
+        elif k == 'beta':
+            return 'be=' + v
+        elif k == 'gamma':
+            return 'ga=' + v
 
     def _parse_system(k, v):
         """
@@ -308,13 +297,13 @@ class IcsdDbImporter(DbImporter):
         :return retval: string
         """
         valid_systems = {
-            "cubic": "CU",
-            "hexagonal": "HE",
-            "monoclinic": "MO",
-            "orthorhombic": "OR",
-            "tetragonal": "TE",
-            "trigonal": "TG",
-            "triclinic": "TC"
+            'cubic': 'CU',
+            'hexagonal': 'HE',
+            'monoclinic': 'MO',
+            'orthorhombic': 'OR',
+            'tetragonal': 'TE',
+            'trigonal': 'TG',
+            'triclinic': 'TC'
         }
 
         return valid_systems[v.lower()]
@@ -346,27 +335,27 @@ class IcsdDbImporter(DbImporter):
                    'crystal_system': ['CRYST_SYS_CODE', _crystal_system_clause],
     }
     # keywords accepted for the web page query
-    keywords = {"id": ("authors", _parse_all),
-                "authors": ("authors", _parse_all),
-                "element": ("elements", _parse_all),
-                "number_of_elements": ("elementc", _parse_all),
-                "mineral_name": ("mineral", _parse_mineral),
-                "chemical_name": ("mineral", _parse_mineral),
-                "formula": ("formula", _parse_all),
-                "volume": ("volume", _parse_volume),
-                "a": ("volume", _parse_volume),
-                "b": ("volume", _parse_volume),
-                "c": ("volume", _parse_volume),
-                "alpha": ("volume", _parse_volume),
-                "beta": ("volume", _parse_volume),
-                "gamma": ("volume", _parse_volume),
-                "spacegroup": ("spaceg", _parse_all),
-                "journal": ("journal", _parse_all),
-                "title": ("title", _parse_all),
-                "year": ("year", _parse_all),
-                "crystal_system": ("system", _parse_system),
+    keywords = {'id': ('authors', _parse_all),
+                'authors': ('authors', _parse_all),
+                'element': ('elements', _parse_all),
+                'number_of_elements': ('elementc', _parse_all),
+                'mineral_name': ('mineral', _parse_mineral),
+                'chemical_name': ('mineral', _parse_mineral),
+                'formula': ('formula', _parse_all),
+                'volume': ('volume', _parse_volume),
+                'a': ('volume', _parse_volume),
+                'b': ('volume', _parse_volume),
+                'c': ('volume', _parse_volume),
+                'alpha': ('volume', _parse_volume),
+                'beta': ('volume', _parse_volume),
+                'gamma': ('volume', _parse_volume),
+                'spacegroup': ('spaceg', _parse_all),
+                'journal': ('journal', _parse_all),
+                'title': ('title', _parse_all),
+                'year': ('year', _parse_all),
+                'crystal_system': ('system', _parse_system),
     }
-    
+
     def query(self, **kwargs):
         """
         Depending on the db_parameters, the mysql database or the web page are queried.
@@ -375,7 +364,7 @@ class IcsdDbImporter(DbImporter):
         :param kwargs: A list of ''keyword = [values]'' pairs.
         """
 
-        if self.db_parameters["querydb"]:
+        if self.db_parameters['querydb']:
             return self._query_sql_db(**kwargs)
         else:
             return self._queryweb(**kwargs)
@@ -390,21 +379,21 @@ class IcsdDbImporter(DbImporter):
 
         sql_where_query = []  # second part of sql query
 
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             if not isinstance(v, list):
                 v = [v]
-            sql_where_query.append("({})".format(self.keywords_db[k][1](self, 
-                                                        self.keywords_db[k][0], 
+            sql_where_query.append('({})'.format(self.keywords_db[k][1](self,
+                                                        self.keywords_db[k][0],
                                                         k, v)))
-        if "crystal_system" in kwargs.keys():  # to query another table than the main one, add LEFT JOIN in front of WHERE
-            sql_query = "LEFT JOIN space_group ON space_group.sgr=icsd.sgr LEFT "\
-                        "JOIN space_group_number ON "\
-                        "space_group_number.sgr_num=space_group.sgr_num "\
-                        + "WHERE" + " AND ".join(sql_where_query)
+        if 'crystal_system' in kwargs.keys():  # to query another table than the main one, add LEFT JOIN in front of WHERE
+            sql_query = 'LEFT JOIN space_group ON space_group.sgr=icsd.sgr LEFT '\
+                        'JOIN space_group_number ON '\
+                        'space_group_number.sgr_num=space_group.sgr_num '\
+                        + 'WHERE' + ' AND '.join(sql_where_query)
         elif sql_where_query:
-            sql_query = "WHERE" + " AND ".join(sql_where_query)
+            sql_query = 'WHERE' + ' AND '.join(sql_where_query)
         else:
-            sql_query = ""
+            sql_query = ''
 
         return IcsdSearchResults(query=sql_query, db_parameters=self.db_parameters)
 
@@ -417,31 +406,30 @@ class IcsdDbImporter(DbImporter):
         :param kwargs: A list of ``keyword = [values]`` pairs
         :return: IcsdSearchResults
         """
-        import urllib
-
+        from urllib.parse import urlencode
         self.actual_args = {
-            "action": "Search",
-            "nb_rows": "100",  # max is 100
-            "order_by": "yearDesc",
-            "authors": "",
-            "volume": "",
-            "mineral": ""
+            'action': 'Search',
+            'nb_rows': '100',  # max is 100
+            'order_by': 'yearDesc',
+            'authors': '',
+            'volume': '',
+            'mineral': ''
         }
 
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             try:
                 realname = self.keywords[k][0]
                 newv = self.keywords[k][1](k, v)
                 # Because different keys correspond to the same search field.
-                if realname in ["authors", "volume", "mineral"]:
-                    self.actual_args[realname] = self.actual_args[realname] + newv + " "
+                if realname in ['authors', 'volume', 'mineral']:
+                    self.actual_args[realname] = self.actual_args[realname] + newv + ' '
                 else:
                     self.actual_args[realname] = newv
-            except KeyError as e:
-                raise TypeError("ICSDImporter got an unexpected keyword argument '{}'".format(e.message))
+            except KeyError as exc:
+                raise TypeError("ICSDImporter got an unexpected keyword argument '{}'".format(exc.args[0]))
 
-        url_values = urllib.urlencode(self.actual_args)
-        query_url = self.db_parameters["urladd"] + url_values
+        url_values = urlencode(self.actual_args)
+        query_url = self.db_parameters['urladd'] + url_values
 
         return IcsdSearchResults(query=query_url, db_parameters=self.db_parameters)
 
@@ -461,7 +449,7 @@ class IcsdDbImporter(DbImporter):
         """
         :return: List of all supported query keywords.
         """
-        if self.db_parameters["querydb"]:
+        if self.db_parameters['querydb']:
             return self.keywords_db.keys()
         else:
             return self.keywords.keys()
@@ -475,8 +463,8 @@ class IcsdSearchResults(DbSearchResults):
     :param db_parameters: database parameter setup during the
       initialisation of the IcsdDbImporter.
     """
-    cif_url = "/index.php?format=cif&action=Export&id%5B%5D={}"
-    db_name = "Icsd"
+    cif_url = '/index.php?format=cif&action=Export&id%5B%5D={}'
+    db_name = 'Icsd'
 
     def __init__(self, query, db_parameters):
 
@@ -485,19 +473,26 @@ class IcsdSearchResults(DbSearchResults):
         self.db_parameters = db_parameters
         self.query = query
         self.number_of_results = None
-        self.results = []
+        self._results = []
         self.cif_numbers = []
         self.entries = {}
         self.page = 1
         self.position = 0
         self.db_version = None
-        self.sql_select_query = "SELECT SQL_CALC_FOUND_ROWS icsd.IDNUM, icsd.COLL_CODE, icsd.STRUCT_FORM "
-        self.sql_from_query = "FROM icsd "
-        
-        if self.db_parameters["querydb"]:
+        self.sql_select_query = 'SELECT SQL_CALC_FOUND_ROWS icsd.IDNUM, icsd.COLL_CODE, icsd.STRUCT_FORM '
+        self.sql_from_query = 'FROM icsd '
+
+        if self.db_parameters['querydb']:
             self.query_db_version()
         self.query_page()
 
+    @property
+    def results(self):
+        """
+        Return the list of results
+        """
+        return self._results
+
     def next(self):
         """
         Return next result as IcsdEntry.
@@ -515,24 +510,24 @@ class IcsdSearchResults(DbSearchResults):
         """
 
         if position < 0 or position >= self.number_of_results:
-            raise IndexError("index out of bounds")
-        while position + 1 >= len(self.results) and len(self.results) < self.number_of_results:
+            raise IndexError('index out of bounds')
+        while position + 1 >= len(self._results) and len(self._results) < self.number_of_results:
             self.page = self.page + 1
             self.query_page()
 
         if position not in self.entries:
-            if self.db_parameters["querydb"]:
-                self.entries[position] = IcsdEntry(self.db_parameters["server"] + 
-                        self.db_parameters["dl_db"] + self.cif_url.format(
-                        self.results[position]),
-                    db_name=self.db_name, id=self.cif_numbers[position], 
-                    version = self.db_version, 
-                    extras={'idnum': self.results[position]})
+            if self.db_parameters['querydb']:
+                self.entries[position] = IcsdEntry(self.db_parameters['server'] +
+                        self.db_parameters['dl_db'] + self.cif_url.format(
+                        self._results[position]),
+                    db_name=self.db_name, id=self.cif_numbers[position],
+                    version = self.db_version,
+                    extras={'idnum': self._results[position]})
             else:
-                self.entries[position] = IcsdEntry(self.db_parameters["server"] + 
-                        self.db_parameters["dl_db"] + self.cif_url.format(
-                        self.results[position]),
-                    db_name=self.db_name, extras={'idnum': self.results[position]})
+                self.entries[position] = IcsdEntry(self.db_parameters['server'] +
+                        self.db_parameters['dl_db'] + self.cif_url.format(
+                        self._results[position]),
+                    db_name=self.db_name, extras={'idnum': self._results[position]})
         return self.entries[position]
 
 
@@ -541,13 +536,13 @@ class IcsdSearchResults(DbSearchResults):
         Query the version of the icsd database (last row of RELEASE_TAGS).
         """
         results = []
-        if self.db_parameters["querydb"]:
+        if self.db_parameters['querydb']:
 
-            sql_select_query = "SELECT RELEASE_TAG "
-            sql_from_query = "FROM icsd.icsd_database_information "
+            sql_select_query = 'SELECT RELEASE_TAG '
+            sql_from_query = 'FROM icsd.icsd_database_information '
 
             self._connect_db()
-            query_statement = "{}{}".format(sql_select_query, sql_from_query)
+            query_statement = '{}{}'.format(sql_select_query, sql_from_query)
             self.cursor.execute(query_statement)
             self.db.commit()
 
@@ -558,12 +553,12 @@ class IcsdSearchResults(DbSearchResults):
             try:
                 self.db_version = results[-1]
             except IndexError:
-                raise IcsdImporterExp("Database version not found")
+                raise IcsdImporterExp('Database version not found')
 
         else:
-            raise NotImplementedError("Cannot query the database version with "
-                                      "a web query.")
-        
+            raise NotImplementedError('Cannot query the database version with '
+                                      'a web query.')
+
     def query_page(self):
         """
         Query the mysql or web page database, depending on the db_parameters.
@@ -572,10 +567,10 @@ class IcsdSearchResults(DbSearchResults):
         :note: Icsd uses its own number system, different from the CIF
                 file numbers.
         """
-        if self.db_parameters["querydb"]:
+        if self.db_parameters['querydb']:
 
             self._connect_db()
-            query_statement = "{}{}{} LIMIT {}, 100".format(self.sql_select_query,
+            query_statement = '{}{}{} LIMIT {}, 100'.format(self.sql_select_query,
                                                             self.sql_from_query,
                                                             self.query,
                                                             (self.page-1)*100)
@@ -583,24 +578,24 @@ class IcsdSearchResults(DbSearchResults):
             self.db.commit()
 
             for row in self.cursor.fetchall():
-                self.results.append(str(row[0]))
+                self._results.append(str(row[0]))
                 self.cif_numbers.append(str(row[1]))
 
             if self.number_of_results is None:
-                self.cursor.execute("SELECT FOUND_ROWS()")
+                self.cursor.execute('SELECT FOUND_ROWS()')
                 self.number_of_results = int(self.cursor.fetchone()[0])
 
             self._disconnect_db()
 
 
         else:
-            import urllib2
             from bs4 import BeautifulSoup
+            from urllib.request import urlopen
             import re
 
-            self.html = urllib2.urlopen(self.db_parameters["server"] + 
-                                        self.db_parameters["db"] + "/" + 
-                                        self.query.format(str(self.page))).read()
+            self.html = urlopen(self.db_parameters['server'] +
+                                self.db_parameters['db'] + '/' +
+                                self.query.format(str(self.page))).read()
 
             self.soup = BeautifulSoup(self.html)
 
@@ -608,12 +603,12 @@ class IcsdSearchResults(DbSearchResults):
 
                 if self.number_of_results is None:
                     self.number_of_results = int(re.findall(r'\d+',
-                                                    str(self.soup.find_all("i")[-1]))[0])
+                                                    str(self.soup.find_all('i')[-1]))[0])
             except IndexError:
                 raise NoResultsWebExp
 
-            for i in self.soup.find_all('input', type="checkbox"):
-                self.results.append(i['id'])
+            for i in self.soup.find_all('input', type='checkbox'):
+                self._results.append(i['id'])
 
     def _connect_db(self):
         """
@@ -642,12 +637,12 @@ class IcsdSearchResults(DbSearchResults):
 class IcsdEntry(CifEntry):
     """
     Represent an entry from Icsd.
-    
+
     :note:
       - Before July 2nd 2015, source['id'] contained icsd.IDNUM (internal
-        icsd id number) and source['extras']['cif_nr'] the cif number 
+        icsd id number) and source['extras']['cif_nr'] the cif number
         (icsd.COLL_CODE).
-      - After July 2nd 2015, source['id'] has been replaced by the cif 
+      - After July 2nd 2015, source['id'] has been replaced by the cif
         number and source['extras']['idnum'] is icsd.IDNUM .
     """
     _license = 'ICSD'
@@ -656,71 +651,42 @@ class IcsdEntry(CifEntry):
         """
         Create an instance of IcsdEntry, related to the supplied URI.
         """
-        super(IcsdEntry, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.source = {
             'db_name': kwargs.get('db_name','Icsd'),
-            'db_uri': None,  # Server ?
-            'id': kwargs.get('id',None),
-            'version': kwargs.get('version',None),
+            'db_uri': None,
+            'id': kwargs.get('id', None),
+            'version': kwargs.get('version', None),
             'uri': uri,
-            'extras': {'idnum': kwargs.get('extras',{}).get('idnum',None)},
+            'extras': {'idnum': kwargs.get('extras', {}).get('idnum', None)},
             'license': self._license,
         }
-        self._cif = None
 
     @property
-    def cif(self):
+    def contents(self):
         """
-        :return: cif file of Icsd entry.
+        Returns raw contents of a file as string. This overrides the DbEntry implementation because
+        the ICSD php backend returns the contents of the CIF in ISO-8859-1 encoding. However, the
+        PyCifRW library (and most other sensible applications), expects UTF-8. Therefore, we decode
+        the original CIF data to unicode and encode it in the UTF-8 format
         """
-        if self._cif is None:
-            import urllib2
+        if self._contents is None:
+            from hashlib import md5
 
-            self._cif = urllib2.urlopen(self.source["uri"]).read()
-        return self._cif
+            self._contents = urlopen(self.source['uri']).read()
+            self._contents = self._contents.decode('iso-8859-1').encode('utf8')
+            self.source['source_md5'] = md5(self._contents).hexdigest()
 
-    def get_cif_node(self):
-        """
-        Create a CIF node, that can be used in AiiDA workflow.
-
-        :return: :py:class:`aiida.orm.data.cif.CifData` object
-        """
-        from aiida.orm.data.cif import CifData
-        import tempfile
-
-        with tempfile.NamedTemporaryFile() as f:
-            f.write(self.cif)
-            f.flush()
-            return CifData(file=f.name, source=self.source)
-
-    def get_corrected_cif(self):
-        """
-        Add quotes to the lines in the author loop if missing.
-
-        :note: ase raises an AssertionError if the quotes in the
-          author loop are missing.
-        """
-        return correct_cif(self.cif)
+        return self._contents
 
     def get_ase_structure(self):
         """
         :return: ASE structure corresponding to the cif file.
         """
-        from aiida.orm.data.cif import CifData
-        import StringIO
+        from aiida.orm import CifData
 
-        return CifData.read_cif(StringIO.StringIO(self.get_corrected_cif()))
-
-
-    def get_aiida_structure(self):
-        """
-        :return: AiiDA structure corresponding to the CIF file.
-        """
-        from aiida.orm import DataFactory
-
-        S = DataFactory("structure")
-        aiida_structure = S(ase=self.get_ase_structure())
-        return aiida_structure
+        cif = correct_cif(self.cif)
+        return CifData.read_cif(StringIO(cif))
 
 
 def correct_cif(cif):
@@ -733,7 +699,7 @@ def correct_cif(cif):
     :param cif: A string containing the content of the CIF file.
     :return: a string containing the corrected CIF file.
     """
-    # Do more checks to be sure it's working in everycase 
+    # Do more checks to be sure it's working in everycase
     # -> no _publ_author_name, several lines, correct input
     lines = cif.split('\n')
 
@@ -747,7 +713,7 @@ def correct_cif(cif):
             words = lines[author_index + inc].split()
             #in case loop is finished -> return cif lines.
             #use regular expressions ?
-            if len(words) == 0 or words[0] == "loop_" or words[0][0] == '_':
+            if len(words) == 0 or words[0] == 'loop_' or words[0][0] == '_':
                 return '\n'.join(lines)
             elif ((words[0][0] == "'" and words[-1][-1] == "'")
                   or (words[0][0] == '"' and words[-1][-1] == '"')):
