@@ -8,6 +8,7 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Tests for the `Node` utils."""
+import pytest
 
 from aiida.backends.testbase import AiidaTestCase
 from aiida.orm import Data
@@ -21,3 +22,8 @@ class TestLoadNodeClass(AiidaTestCase):
         """Verify that `load_node_class` will fall back to `Data` class if entry point cannot be loaded."""
         loaded_class = load_node_class('data.some.non.existing.plugin.')
         self.assertEqual(loaded_class, Data)
+
+        # For really unresolvable type strings, we fall back onto the `Data` class
+        with pytest.warns(UserWarning):
+            loaded_class = load_node_class('__main__.SubData.')
+        self.assertEqual(loaded_class, Data)
